@@ -13,6 +13,7 @@ from sanic.request import Request
 from typing import Text, List, Dict, Any, Optional, Callable, Iterable, Awaitable
 
 import rasa.utils.endpoints
+from rasa.cli import utils as cli_utils
 from rasa.constants import DOCS_BASE_URL
 from rasa.core import utils
 
@@ -40,8 +41,22 @@ class UserMessage(object):
             input_channel: Text = None,
             message_id: Text = None,
             asrConfidence: Dict[Text, Any] = None,
-            recordingId: Dict[Text, Any] = None
+            recordingId: Dict[Text, Any] = None,
+            metadata: Optional[Dict] = None,
     ) -> None:
+        """Creates a ``UserMessage`` object.
+
+        Args:
+            text: the message text content.
+            output_channel: the output channel which should be used to send
+                bot responses back to the user.
+            sender_id: the message owner ID.
+            parse_data: rasa data about the message.
+            input_channel: the name of the channel which received this message.
+            message_id: ID of the message.
+            metadata: additional metadata for this message.
+
+        """
         self.text = text.strip() if text else text
 
         self.recording_id = recordingId
@@ -65,6 +80,7 @@ class UserMessage(object):
         self.input_channel = input_channel
 
         self.parse_data = parse_data
+        self.metadata = metadata
 
 
 def register(
@@ -80,40 +96,7 @@ def register(
             p = None
         app.blueprint(channel.blueprint(handler), url_prefix=p)
 
-
-def button_to_string(button, idx=0):
-    """Create a string representation of a button."""
-
-    title = button.pop("title", "")
-
-    if "payload" in button:
-        payload = " ({})".format(button.pop("payload"))
-    else:
-        payload = ""
-
-    # if there are any additional attributes, we append them to the output
-    if button:
-        details = " - {}".format(json.dumps(button, sort_keys=True))
-    else:
-        details = ""
-
-    button_string = "{idx}: {title}{payload}{details}".format(
-        idx=idx + 1, title=title, payload=payload, details=details
-    )
-
-    return button_string
-
-
-def element_to_string(element, idx=0):
-    """Create a string representation of an element."""
-
-    title = element.pop("title", "")
-
-    element_string = "{idx}: {title} - {element}".format(
-        idx=idx + 1, title=title, element=json.dumps(element, sort_keys=True)
-    )
-
-    return element_string
+    app.input_channels = input_channels
 
 
 class InputChannel(object):
@@ -268,7 +251,7 @@ class OutputChannel(object):
 
         await self.send_text_message(recipient_id, text, **kwargs)
         for idx, button in enumerate(buttons):
-            button_msg = button_to_string(button, idx)
+            button_msg = cli_utils.button_to_string(button, idx)
             await self.send_text_message(recipient_id, button_msg, **kwargs)
 
     async def send_quick_replies(
