@@ -180,7 +180,7 @@ class UserUttered(Event):
 
     def __init__(
         self,
-        text,
+        text: Optional[Text] = None,
         intent=None,
         entities=None,
         parse_data=None,
@@ -189,13 +189,15 @@ class UserUttered(Event):
         message_id=None,
         asrConfidence=None,
         recordingId=None,
-        missed_intent=None
+        missed_intent=None,
+        metadata: Optional[Dict] = None,
     ):
         self.text = text
         self.intent = intent if intent else {}
         self.entities = entities if entities else []
         self.input_channel = input_channel
         self.message_id = message_id
+        self.metadata = metadata
 
         self.asr_confidence = asrConfidence if asrConfidence is not None else 1
         self.recording_id = recordingId if recordingId else None
@@ -215,13 +217,21 @@ class UserUttered(Event):
                 "asrConfidence": self.asr_confidence,
                 "recordingId": self.recording_id,
                 "missed_intent": self.missed_intent,
-                "message_id": self.message_id
+                "message_id": self.message_id,
+                "metadata": self.metadata,
             }
 
         super(UserUttered, self).__init__(timestamp)
 
     @staticmethod
-    def _from_parse_data(text, parse_data, timestamp=None, input_channel=None):
+    def _from_parse_data(
+        text: Text,
+        parse_data: Dict[Text, Any],
+        timestamp: Optional[int] = None,
+        input_channel: Optional[Text] = None,
+        message_id: Optional[Text] = None,
+        metadata: Optional[Dict] = None,
+    ):
         return UserUttered(
             text,
             parse_data.get("intent"),
@@ -229,6 +239,8 @@ class UserUttered(Event):
             parse_data,
             timestamp,
             input_channel,
+            message_id,
+            metadata,
         )
 
     def __hash__(self):
@@ -259,19 +271,18 @@ class UserUttered(Event):
     def empty():
         return UserUttered(None)
 
-    def as_dict(self):
-        d = super(UserUttered, self).as_dict()
-        input_channel = None  # for backwards compatibility (persisted evemts)
-        if hasattr(self, "input_channel"):
-            input_channel = self.input_channel
-        d.update(
+    def as_dict(self) -> Dict[Text, Any]:
+        _dict = super(UserUttered, self).as_dict()
+        _dict.update(
             {
                 "text": self.text,
                 "parse_data": self.parse_data,
-                "input_channel": input_channel,
+                "input_channel": getattr(self, "input_channel", None),
+                "message_id": getattr(self, "message_id", None),
+                "metadata": getattr(self, "metadata", None),
             }
         )
-        return d
+        return _dict
 
     @classmethod
     def _from_story_string(cls, parameters: Dict[Text, Any]) -> Optional[List[Event]]:
@@ -282,6 +293,8 @@ class UserUttered(Event):
                     parameters.get("parse_data"),
                     parameters.get("timestamp"),
                     parameters.get("input_channel"),
+                    parameters.get("message_id"),
+                    parameters.get("metadata"),
                 )
             ]
         except KeyError as e:
