@@ -149,7 +149,7 @@ class MessageProcessor(object):
         self,
         sender_id: Text,
         action_name: Text,
-        output_channel: CollectingOutputChannel,
+        output_channel: OutputChannel,
         nlg: NaturalLanguageGenerator,
         policy: Text,
         confidence: float,
@@ -329,7 +329,8 @@ class MessageProcessor(object):
                 recordingId=message.recording_id,
                 input_channel=message.input_channel,
                 message_id=message.message_id,
-                missed_intent=missed_intent
+                missed_intent=missed_intent,
+                metadata=message.metadata,
             ),
             self.domain,
         )
