@@ -20,6 +20,7 @@ from rasa.core.tracker_store import TrackerStore
 from rasa.core.utils import AvailableEndpoints, configure_file_logging
 from rasa.model import get_model_subdirectories, get_model
 from rasa.utils.common import update_sanic_log_level, class_from_module_path
+from rasa.server import add_root_route
 
 logger = logging.getLogger()  # get the root logger
 
@@ -67,6 +68,13 @@ def _create_single_channel(channel, credentials):
             )
 
 
+def _create_app_without_api(cors: Optional[Union[Text, List[Text]]] = None):
+    app = Sanic(__name__, configure_logging=False)
+    add_root_route(app)
+    CORS(app, resources={r"/*": {"origins": cors or ""}}, automatic_options=True)
+    return app
+
+
 def configure_app(
     input_channels: Optional[List["InputChannel"]] = None,
     cors: Optional[Union[Text, List[Text]]] = None,
@@ -93,8 +101,7 @@ def configure_app(
             endpoints=endpoints,
         )
     else:
-        app = Sanic(__name__, configure_logging=False)
-        CORS(app, resources={r"/*": {"origins": cors or ""}}, automatic_options=True)
+        app = _create_app_without_api(cors)
 
     if input_channels:
         rasa.core.channels.channel.register(input_channels, app, route=route)
@@ -173,13 +180,17 @@ def serve_application(
     )
 
     async def clear_model_files(app: Sanic, _loop: Text) -> None:
+        from rasa.nlu.extractors.duckling_http_extractor import session
+
         if app.agent.model_directory:
             shutil.rmtree(app.agent.model_directory)
+        if session:
+            await session.close()
 
     app.register_listener(clear_model_files, "after_server_stop")
 
     update_sanic_log_level(log_file)
-    num_workers = max(int(os.environ.get("NUM_WORKERS", os.cpu_count() - 2)), 1)
+    num_workers = int(os.environ.get("NUM_WORKERS", 1))
     logger.info("Spawning {} Sanic workers....".format(num_workers))
     app.run(host="0.0.0.0", port=port, access_log=False, workers=num_workers)
 
