@@ -426,7 +426,7 @@ class SQLTrackerStore(TrackerStore):
         from sqlalchemy.orm import sessionmaker
         from sqlalchemy import create_engine
 
-        engine_url = self._get_db_url(
+        engine_url = self.get_db_url(
             dialect, host, port, db, username, password, login_db
         )
         logger.debug(
@@ -469,7 +469,7 @@ class SQLTrackerStore(TrackerStore):
         super(SQLTrackerStore, self).__init__(domain, event_broker)
 
     @staticmethod
-    def _get_db_url(
+    def get_db_url(
         dialect: Text = "sqlite",
         host: Optional[Text] = None,
         port: Optional[int] = None,
@@ -478,6 +478,23 @@ class SQLTrackerStore(TrackerStore):
         password: Text = None,
         login_db: Optional[Text] = None,
     ) -> Union[Text, "URL"]:
+        """Builds an SQLAlchemy `URL` object representing the parameters needed
+        to connect to an SQL database.
+
+        Args:
+            dialect: SQL database type.
+            host: Database network host.
+            port: Database network port.
+            db: Database name.
+            username: User name to use when connecting to the database.
+            password: Password for database user.
+            login_db: Alternative database name to which initially connect, and create
+                the database specified by `db` (PostgreSQL only).
+
+        Returns:
+            URL ready to be used with an SQLAlchemy `Engine` object.
+
+        """
         from urllib.parse import urlsplit
         from sqlalchemy.engine.url import URL
 
