@@ -3,7 +3,8 @@ import logging
 import os
 import tempfile
 import traceback
-from functools import wraps
+import time
+from functools import wraps, reduce
 from inspect import isawaitable
 from typing import Any, Callable, List, Optional, Text, Union
 
@@ -29,7 +30,11 @@ from rasa.constants import (
 )
 from rasa.core import broker
 from rasa.core.agent import load_agent, Agent
-from rasa.core.channels.channel import UserMessage, CollectingOutputChannel
+from rasa.core.channels.channel import (
+    UserMessage,
+    CollectingOutputChannel,
+    OutputChannel,
+)
 from rasa.core.events import Event
 from rasa.core.test import test
 from rasa.core.trackers import DialogueStateTracker, EventVerbosity
@@ -42,6 +47,10 @@ from rasa.core.tracker_store import TrackerStore
 
 logger = logging.getLogger(__name__)
 
+OUTPUT_CHANNEL_QUERY_KEY = "output_channel"
+USE_LATEST_INPUT_CHANNEL_AS_OUTPUT_CHANNEL = "latest"
+
+
 class ErrorResponse(Exception):
     def __init__(self, status, reason, message, details=None, help_url=None):
         self.error_info = {
@@ -279,6 +288,13 @@ async def _load_agent(
     return loaded_agent
 
 
+def add_root_route(app: Sanic):
+    @app.get("/")
+    async def hello(request: Request):
+        """Check if the server is running and responds with the version."""
+        return response.text("Hello from Rasa: " + rasa.__version__)
+
+
 def create_app(
     agent: Optional["Agent"] = None,
     cors_origins: Union[Text, List[Text]] = "*",
@@ -319,6 +335,13 @@ def create_app(
         initialize_tracer('hydra')
         app.session = aiohttp.ClientSession()
 
+    @app.listener('before_server_stop')
+    async def close_session(app, loop):
+        logger.info("Shutting down Sanic server now...")
+
+        if app.session:
+            await app.session.close()
+
     @app.exception(ErrorResponse)
     async def handle_error_response(request: Request, exception: ErrorResponse):
         return response.json(exception.error_info, status=exception.status)
@@ -382,11 +405,11 @@ def create_app(
             if endpoints.duckling:
                 duckling_resp = await app.session.get(endpoints.duckling.url, timeout=timeout)
 
-            if not app.agent.is_ready():
+            if not app.agent.is_ready(allow_nlu_only=True):
                 raise ErrorResponse(500, "AgentError", "Agent is not ready yet.")
-            elif action_resp.status != 200:
+            elif action_resp and action_resp.status != 200:
                 raise ErrorResponse(500, "ActionServerError", "Action server is not ready yet.")
-            elif duckling_resp.status != 200:
+            elif duckling_resp and duckling_resp.status != 200:
                 raise ErrorResponse(500, "DucklingServerError", "Duckling server is not ready yet.")
 
             logger.info({"event": "HEALTH_CHECK", "message": "Dialog Manager is ready."})
@@ -578,13 +601,13 @@ def create_app(
 
         policy = request_params.get("policy", None)
         confidence = request_params.get("confidence", None)
-
         verbosity = event_verbosity_parameter(request, EventVerbosity.AFTER_RESTART)
 
         try:
-            out = CollectingOutputChannel()
+            tracker = await obtain_tracker_store(app.agent, conversation_id)
+            output_channel = _get_output_channel(request, tracker)
             await app.agent.execute_action(
-                conversation_id, action_to_execute, out, policy, confidence
+                conversation_id, action_to_execute, output_channel, policy, confidence
             )
         except Exception as e:
             logger.debug(traceback.format_exc())
@@ -596,7 +619,13 @@ def create_app(
 
         tracker = await obtain_tracker_store(app.agent, conversation_id)
         state = tracker.current_state(verbosity)
-        return response.json({"tracker": state, "messages": out.messages})
+
+        response_body = {"tracker": state}
+
+        if isinstance(output_channel, CollectingOutputChannel):
+            response_body["messages"] = output_channel.messages
+
+        return response.json(response_body)
 
     @app.post("/conversations/<conversation_id>/predict")
     @requires_auth(app, auth_token)
@@ -893,6 +922,90 @@ def create_app(
                 )
             response_data = emulator.normalise_response_json(parsed_data)
 
+            # Publish the payload through the event broker.
+            try:
+                _broker = app.agent.tracker_store.event_broker
+                if _broker:
+                    event = {
+                        'sender_id': 'NA',
+                        'event': 'nlu',
+                        'timestamp': time.time(),
+                        'parse_data': response_data,
+                        'text': response_data["text"],
+                        'channel': 'rest'
+                    }
+                    logger.info(f"NLU parse: {event}")
+                    _broker.publish(event)
+                else:
+                    logger.warning("No event broker is configured, skipping events publish.")
+            except Exception as e:
+                logger.debug(traceback.format_exc())
+                raise ErrorResponse(
+                    500, "EventBrokerError", "An unexpected error occurred. Error: {}".format(e)
+                )
+
+            return response.json(response_data)
+
+        except Exception as e:
+            logger.debug(traceback.format_exc())
+            raise ErrorResponse(
+                500, "ParsingError", "An unexpected error occurred. Error: {}".format(e)
+            )
+    
+    @app.post("/model/parseList")
+    @requires_auth(app, auth_token)
+    async def parseList(request: Request):
+        validate_request_body(
+            request,
+            "No text message defined in request_body. Add text message to request body "
+            "in order to obtain the intent and extracted entities.",
+        )
+        emulation_mode = request.args.get("emulation_mode")
+        emulator = _create_emulator(emulation_mode)
+
+        try:
+            phrase_list = []
+            for phrase in request.json['text']:
+                phrase_list.append({'text': phrase, 'time': None})
+            try:
+                predList = []
+                for phrase in phrase_list:    
+                    parsed_data = await app.agent.parse_message_using_nlu_interpreter(
+                        phrase['text']
+                    )
+                    predList.append(parsed_data)
+                
+            except Exception as e:
+                logger.debug(traceback.format_exc())
+                raise ErrorResponse(
+                    400,
+                    "ParsingError",
+                    "An unexpected error occurred. Error: {}".format(e),
+                )
+            response_data = predList
+
+            # Publish the payload through the event broker.
+            try:
+                _broker = app.agent.tracker_store.event_broker
+                if _broker:
+                    event = {
+                        'sender_id': 'NA',
+                        'event': 'nlu',
+                        'timestamp': time.time(),
+                        'parse_data': response_data,
+                        'text': response_data["text"],
+                        'channel': 'rest'
+                    }
+                    logger.info(f"NLU parse: {event}")
+                    _broker.publish(event)
+                else:
+                    logger.warning("No event broker is configured, skipping events publish.")
+            except Exception as e:
+                logger.debug(traceback.format_exc())
+                raise ErrorResponse(
+                    500, "EventBrokerError", "An unexpected error occurred. Error: {}".format(e)
+                )
+
             return response.json(response_data)
 
         except Exception as e:
@@ -967,3 +1080,43 @@ def create_app(
     CHAT_LATENCY.labels('', '').time()
 
     return app
+
+
+def _get_output_channel(
+    request: Request, tracker: Optional[DialogueStateTracker]
+) -> OutputChannel:
+    """Returns the `OutputChannel` which should be used for the bot's responses.
+
+    Args:
+        request: HTTP request whose query parameters can specify which `OutputChannel`
+                 should be used.
+        tracker: Tracker for the conversation. Used to get the latest input channel.
+
+    Returns:
+        `OutputChannel` which should be used to return the bot's responses to.
+    """
+    requested_output_channel = request.args.get(OUTPUT_CHANNEL_QUERY_KEY)
+
+    if (
+        requested_output_channel == USE_LATEST_INPUT_CHANNEL_AS_OUTPUT_CHANNEL
+        and tracker
+    ):
+        requested_output_channel = tracker.get_latest_input_channel()
+
+    # Interactive training does not set `input_channels`, hence we have to be cautious
+    registered_input_channels = getattr(request.app, "input_channels", None) or []
+    matching_channels = [
+        channel
+        for channel in registered_input_channels
+        if channel.name() == requested_output_channel
+    ]
+
+    # Check if matching channels can provide a valid output channel,
+    # otherwise use `CollectingOutputChannel`
+    return reduce(
+        lambda output_channel_created_so_far, input_channel: (
+            input_channel.get_output_channel() or output_channel_created_so_far
+        ),
+        matching_channels,
+        CollectingOutputChannel(),
+    )
